# protontime


`protontime` is a dart library that converts a date into a humanized text. Instead of showing a date  `2024-01-01 01:01`  with `protontime` you can display something like `"now", "5 sec ago", "an hour ago", etc`


A Flutter plugin for managing timestamps.


|             | Android | iOS   | Linux | macOS  | Web | Windows     |
|-------------|---------|-------|-------|--------|-----|-------------|
| **Support** | SDK 16+ | 12.0+ | Any   | 10.14+ | Any | Windows 10+ |




## Installation

With Dart:
```bash
dart pub add protontime
```

With Flutter:
```bash
flutter pub add protontime
```

This will add a line like this to your package's pubspec.yaml (and run an implicit flutter pub get):

```yaml
dependencies:
  protontime: ^latest
```

Alternatively, your editor might support flutter pub get. Check the docs for your editor to learn more.


## Import it


Now in your Dart code, you can use:

```dart
import 'package:protontime/protontime.dart';
```

## Usage
The easiest way to use this library via top-level function `format(date)`:

### Quick Usage

#### DateTime
```dart
import 'package:protontime/protontime.dart';

main() {
    Duration fiveMin = Duration(days: 5); // 120:00:00.000000
    DateTime fiveMinAdd = DateTime.now().add(fiveMin); // 2024-03-02 03:00:05.270034
    DateTime fiveMinSub = DateTime.now().subtract(fiveMin); // 2024-02-21 03:00:05.277179

    final resultPast = Protontime.format(fiveMinSub); // 5 days ago
    final resultFuture = Protontime.format(fiveMinAdd); // 5 days from now

    print("Past Time: $resultPast"); // 5 days ago
    print('Future Time: $resultFuture'); // 5 days from now
}
```

#### Timestamp
```dart
import 'package:protontime/protontime.dart';

main() {
    DateTime timestamp = DateTime.parse("2024-01-01T00:00:00.000000Z");
    final resultTimestamp = Protontime.format(timestamp); // 5 days ago

    print("Timestamp Time: $resultTimestamp"); // 5 days ago
}
```
### Basic Usage (`Short Messages`)

```dart
import 'package:protontime/protontime.dart';

main() {
    Duration fiveMin = Duration(days: 5); // 120:00:00.000000
    DateTime fiveMinAdd = DateTime.now().add(fiveMin); // 2024-03-02 03:00:05.270034
    DateTime fiveMinSub = DateTime.now().subtract(fiveMin); // 2024-02-21 03:00:05.277179

    final resultPastShort = Protontime.format(
      fiveMinSub,
      short: true,
    ); // 5d

    final resultFutureShort = Protontime.format(
      fiveMinAdd,
      short: true,
    ); // 5d

    print("Past Short Time: $resultPast"); // 5d
    print('Future Short Time: $resultFuture'); // 5d
}
```
    
## Language
The simplest method to format timestamps using local language is with `protontime`.


```dart
import 'package:protontime/protontime.dart';

main() {
    Duration fiveMin = Duration(days: 5); // 120:00:00.000000
    DateTime fiveMinAdd = DateTime.now().add(fiveMin); // 2024-03-02 03:00:05.270034
    DateTime fiveMinSub = DateTime.now().subtract(fiveMin); // 2024-02-21 03:00:05.277179

    final resultEsp = Protontime.format(
      fiveMinSub,
      language: 'es',
    ); //  hace 5 días

    final resultEspShort = Protontime.format(
      fiveMinAdd,
      language: 'es',
      short: true,
    ); //  5 días

    print("Local Lanugage: $resultEsp"); //  hace 5 días
    print('Local Lanugage Short: $resultEspShort'); //  5 días
}
```
## Supported Language
Supported languages include Amharic, Arabic, Azerbaijani, and many more.

| Flag | Language               | Language Code |
|------|------------------------|---------------|
| ![Flag](https://www.flagsapi.com/ET/flat/64.png)  | Amharic                | am            |
| ![Flag](https://www.flagsapi.com/SA/flat/64.png)  | Arabic                 | ar            |
| ![Flag](https://www.flagsapi.com/AZ/flat/64.png)  | Azerbaijani            | az            |
| ![Flag](https://www.flagsapi.com/BY/flat/64.png)  | Belarusian             | be            |
| ![Flag](https://www.flagsapi.com/BA/flat/64.png)  | Bosnian                | bs            |
| ![Flag](https://www.flagsapi.com/AD/flat/64.png)  | Catalan                | ca            |
| ![Flag](https://www.flagsapi.com/CZ/flat/64.png)  | Czech                  | cs            |
| ![Flag](https://www.flagsapi.com/DK/flat/64.png)  | Danish                 | da            |
| ![Flag](https://www.flagsapi.com/DE/flat/64.png)  | German                 | de            |
| ![Flag](https://www.flagsapi.com/MV/flat/64.png)  | Dhivehi                | dv            |
| ![Flag](https://www.flagsapi.com/GB/flat/64.png)  | English                | en            |
| ![Flag](https://www.flagsapi.com/ES/flat/64.png)  | Spanish                | es            |
| ![Flag](https://www.flagsapi.com/EE/flat/64.png)  | Estonian               | et            |
| ![Flag](https://www.flagsapi.com/IR/flat/64.png)  | Persian                | fa            |
| ![Flag](https://www.flagsapi.com/FI/flat/64.png)  | Finnish                | fi            |
| ![Flag](https://www.flagsapi.com/FR/flat/64.png)  | French                 | fr            |
| ![Flag](https://www.flagsapi.com/GR/flat/64.png)  | Greek                  | gr            |
| ![Flag](https://www.flagsapi.com/IL/flat/64.png)  | Hebrew                 | he            |
| ![Flag](https://www.flagsapi.com/IN/flat/64.png)  | Hindi                  | hi            |
| ![Flag](https://www.flagsapi.com/HU/flat/64.png)  | Hungarian              | hu            |
| ![Flag](https://www.flagsapi.com/ID/flat/64.png)  | Indonesian             | id            |
| ![Flag](https://www.flagsapi.com/IT/flat/64.png)  | Italian                | it            |
| ![Flag](https://www.flagsapi.com/JP/flat/64.png)  | Japanese               | ja            |
| ![Flag](https://www.flagsapi.com/KH/flat/64.png)  | Khmer                  | km            |
| ![Flag](https://www.flagsapi.com/KR/flat/64.png)  | Korean                 | ko            |
| ![Flag](https://www.flagsapi.com/KW/flat/64.png)  | Kurdish                | ku            |
| ![Flag](https://www.flagsapi.com/LV/flat/64.png)  | Latvian                | lv            |
| ![Flag](https://www.flagsapi.com/MN/flat/64.png)  | Mongolian              | mn            |
| ![Flag](https://www.flagsapi.com/MY/flat/64.png)  | Malay                  | ms_my         |
| ![Flag](https://www.flagsapi.com/NO/flat/64.png)  | Norwegian Bokmål       | nb_no         |
| ![Flag](https://www.flagsapi.com/NL/flat/64.png)  | Dutch                  | nl            |
| ![Flag](https://www.flagsapi.com/NO/flat/64.png)  | Norwegian Nynorsk      | nn_no         |
| ![Flag](https://www.flagsapi.com/PL/flat/64.png)  | Polish                 | pl            |
| ![Flag](https://www.flagsapi.com/BR/flat/64.png)  | Portuguese (Brazil)    | pt_br         |
| ![Flag](https://www.flagsapi.com/RO/flat/64.png)  | Romanian               | ro            |
| ![Flag](https://www.flagsapi.com/RU/flat/64.png)  | Russian                | ru            |
| ![Flag](https://www.flagsapi.com/RW/flat/64.png)  | Kinyarwanda            | rw            |
| ![Flag](https://www.flagsapi.com/RS/flat/64.png)  | Serbian                | sr            |
| ![Flag](https://www.flagsapi.com/SE/flat/64.png)  | Swedish                | sv            |
| ![Flag](https://www.flagsapi.com/LK/flat/64.png)  | Tamil                  | ta            |
| ![Flag](https://www.flagsapi.com/TH/flat/64.png)  | Thai                   | th            |
| ![Flag](https://www.flagsapi.com/TM/flat/64.png)  | Turkmen                | tk            |
| ![Flag](https://www.flagsapi.com/TR/flat/64.png)  | Turkish                | tr            |
| ![Flag](https://www.flagsapi.com/UA/flat/64.png)  | Ukrainian              | uk            |
| ![Flag](https://www.flagsapi.com/PK/flat/64.png)  | Urdu                   | ur            |
| ![Flag](https://www.flagsapi.com/VN/flat/64.png)  | Vietnamese             | vi            |
| ![Flag](https://www.flagsapi.com/CN/flat/64.png)  | Chinese (Simplified)   | zh_ch         |
| ![Flag](https://www.flagsapi.com/CN/flat/64.png)  | Chinese (Traditional)  | zh            |



## Scope

While there have been numerous requests for additional complex features, I aim to maintain this library's simplicity to minimize the need for ongoing maintenance.

The focus of this library should be

1. Offering a singular `format` function that converts a `date` into a human-readable `format`.
2. Allowing users to incorporate their own languages or override existing ones as desired through customizable abstractions.
3. Offer languages contributed by the community for users to incorporate as needed, avoiding the inclusion of all languages by default.
4. The library should be dependency-free.
